#
# spec file for package fwupdate
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%ifarch %{x86} x86_64
# as soon as the kernel support SMBIOS calls over ACPI-WMI,
# this is no longer needed
%bcond_without libsmbios
%else
%bcond_with libsmbios
%endif

Name:           fwupdate
Version:        12
Release:        lp151.4.3.1
Summary:        Tools to manage UEFI firmware updates
License:        GPL-2.0-or-later
Group:          System/Base
Url:            https://github.com/rhinstaller/fwupdate
Source0:        https://github.com/rhboot/fwupdate/releases/download/%{version}/%{name}-%{version}.tar.bz2
Patch0:         %{name}-suse-build.patch
Patch1:         %{name}-bsc1152928-update-aarch64-linker-script.patch
BuildRequires:  efivar-devel >= 34
BuildRequires:  elfutils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gnu-efi >= 3.0.2
%if %{with libsmbios}
BuildRequires:  libsmbios-devel
%endif
BuildRequires:  pesign-obs-integration
BuildRequires:  pkg-config
BuildRequires:  popt-devel
BuildRequires:  systemd-rpm-macros
Requires:       %{name}-efi
Requires:       efibootmgr
Requires:       libfwup1 = %{version}-%{release}
%ifarch x86_64
Requires:       shim >= 11
%endif
%{?systemd_requires}
ExclusiveArch:  x86_64 %{ix86} aarch64

%if 0%{?is_opensuse}
%global efidir opensuse
%else
%global efidir sles
%endif

%undefine _unique_debug_names
%if 0%{?suse_version} > 1500
%define sysefibasedir  %{_datadir}/efi
%define sysefidir      %{sysefibasedir}/%{_target_cpu}
%else
%define sysefidir      %{_libdir}/efi
%endif

%description
fwupdate provides a simple command line interface to the UEFI firmware updates.

%package -n libfwup1
Summary:        Library to manage UEFI firmware updates
Group:          System/Libraries

%description -n libfwup1
Library to allow for the simple manipulation of UEFI firmware updates.

%package devel
Summary:        Development headers for libfwup
Group:          Development/Libraries/Other
Requires:       efivar-devel >= 34
Requires:       fwupdate = %{version}-%{release}
Requires:       libfwup1 = %{version}-%{release}

%description devel
development headers required to use libfwup.

%package efi
Summary:        UEFI binaries used by libfwup
Group:          System/Base
%ifarch x86_64
Requires:       shim
%endif

%description efi
UEFI binaries used by libfwup to update the firmware.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1
%patch1 -p1

%build
make PJONES="$RPM_OPT_FLAGS" libdir=%{_libdir} bindir=%{_bindir} \
     EFIDIR=%{efidir} GNUEFIDIR=%{_libdir} TARGETDIR=%{sysefidir} \
     %{?_smp_mflags}

%install
export BRP_PESIGN_FILES='%{_libdir}/efi/fwup*.efi'
%make_install libdir=%{_libdir} bindir=%{_bindir} mandir=%{_mandir} \
              localedir=%{_datadir}/locale/ includedir=%{_includedir} \
	      libexecdir=%{_libexecdir} datadir=%{_datadir} EFIDIR=%{efidir} \
              TARGETDIR=%{sysefidir}

echo 0%{?_build_create_debug}
%if 0%{?_build_create_debug} == 0
rm -rf %{buildroot}/usr/src/debug/%{name}*
rm -f  %{buildroot}/usr/lib/debug/%{sysefidir}/fwup*.efi.debug
%endif

%fdupes %{buildroot}%{_mandir}/*

# create rcsymlink
mkdir -p %{buildroot}%{_sbindir}
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rcfwupdate-cleanup

%pre
%service_add_pre fwupdate-cleanup.service

%post
%service_add_post fwupdate-cleanup.service

%preun
%service_del_preun fwupdate-cleanup.service

%postun
%service_del_postun fwupdate-cleanup.service

%post -n libfwup1 -p /sbin/ldconfig

%postun -n libfwup1 -p /sbin/ldconfig

%posttrans -n %{name}-efi
# Create the directory for the firwmare update capsule
mkdir -p /boot/efi/EFI/%{efidir}/fw
# Install the UEFI firmware update program
cp %{sysefidir}/fwup*.efi /boot/efi/EFI/%{efidir}

%postun -n %{name}-efi
if [ "$1" = 0 ] ; then
	# Remove all the capsules
	rm -rf /boot/efi/EFI/%{efidir}/fw
	# Remove the UEFI firmware update program
	rm -f /boot/efi/EFI/%{efidir}/fwup*.efi
fi

%files
%defattr(-,root,root)
%license COPYING
%{_bindir}/fwupdate
%doc %{_mandir}/man1/*
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/fwupdate
%{_unitdir}/fwupdate-cleanup.service
%ghost %attr(0755,root,root) %dir %{_rundir}/fwupdate/
%attr(0755,root,root) %dir %{_libexecdir}/fwupdate/
%{_libexecdir}/fwupdate/cleanup
%{_sbindir}/rcfwupdate-cleanup

%files devel
%defattr(-,root,root)
%doc %{_mandir}/man3/*
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n libfwup1
%defattr(-,root,root)
%{_libdir}/*.so.*

%files efi
%defattr(-,root,root)
%dir %{?sysefibasedir}
%dir %{sysefidir}
%{sysefidir}/fwup*.efi

%changelog
* Wed Oct 16 2019 Gary Ching-Pang Lin <glin@suse.com>
- Add fwupdate-bsc1152928-update-aarch64-linker-script.patch to
  update the linker script for AArch64 to match the one in
  gnu-efi (bsc#1152928)
* Mon Jan 28 2019 Gary Ching-Pang Lin <glin@suse.com>
- Fix the destination of 'efi'-executables for i586 (FATE#326960)
* Thu Jan 17 2019 rw@suse.com
- Move 'efi'-executables to '/usr/share/efi'  (FATE#326960)
* Tue Oct 23 2018 Gary Ching-Pang Lin <glin@suse.com>
- Amend the spec file to avoid fwup*.efi from being removed
  mistakenly (bsc#1112832)
* Thu Jul 19 2018 bjorn.lie@gmail.com
- Update to version 12 (FATE#326702)
  + Better CI.
  + Limit how large our WMI buffer can be.
  + Add fwup_version() because fwupd wants it.
  + Fix linking on (some) platforms that need libgcc_eh.a.
  + abicheck improvements.
  + Default to creating a UX capsule, whatever it may actually do.
- Refresh fwupdate-suse-build.patch with quilt.
- Use url for source tarball and license tag for COPYING.
* Thu Jun 28 2018 glin@suse.com
- Correct the requirement of efivar-devel version
* Wed Jun 20 2018 oliver@getspam.de
- Update to version 11
  + lots of fixes from cov-scan and clang analyzer
  + support for Lenovo machines
  + experimental support for UI Capsules
  + Dell WMI support
  + lots of bugfixes
  + configurable EFI ESP location by setting ESPMOUNTPOINT or the git
    config property fwupdate.espmountdir during the build.
  + Lots of coverity work
  + ABI compatibility checking during the release process
  + Make subdirectory builds work
- removed fwupdate-list-firmware-types.patch
* Mon Apr  9 2018 glin@suse.com
- Require shim only for x86_64 (bsc#1088434)
* Fri Feb  9 2018 glin@suse.com
- Remove fwupdate-bsc988886-add-leading-space.patch and bump the
  shim version requirement since we got the new signature for shim
  (bsc#1054712)
* Mon Dec 18 2017 mls@suse.de
- bring back accidental removed needssslcertforbuild
* Fri Dec 15 2017 stefan.bruens@rwth-aachen.de
- EFI updates through fwupdate are also possible on Aarch64.
  smbios support is only relevant for some Dell machines, i.e.
  x86 only.
* Thu Dec 14 2017 mls@suse.de
- disable _unique_debug_names fow now
  fwupdate wants to install it's own debug files, but doesn't know
  about this option yet
* Mon Nov 20 2017 glin@suse.com
- Add back fwupdate-bsc988886-add-leading-space.patch due to the
  long pending shim signature request. Also drop the shim version
  requirement.
* Tue Aug 29 2017 glin@suse.com
- Update to 9+git21.gcd8f7d7 (FATE#322805)
- Add the new BuildRequires: libsmbios-devel
- Update the so version of libfwup
- Refresh fwupdate-suse-build.patch
- Remove the upstream patches
  + fwupdate-fix-efivar-0.24-api.patch
  + fwupdate-bsc988000-set-a-mode-with-efi_set_variable.patch
  + fwupdate-unset-immutable-flag.patch
- Drop fwupdate-bsc988886-add-leading-space.patch (Need shim >= 11)
- Add fwupdate-list-firmware-types.patch to list the supported
  firmware types
* Thu Mar 30 2017 glin@suse.com
- Remove the debug source and info of the EFI files when disabling
  the debug build (bsc#1031554)
  + Also remove the efi-debuginfo subpackage since the debug file
    is packaged correctly now.
* Thu Mar  9 2017 rw@suse.com
- Enable efivar API patch based on pkg-config data and require
  at least gnu-efi-3.0.2.  (ramification of FATE#322108)
* Thu Jul 28 2016 glin@suse.com
- Relax the requirement of efivar-devel and disable the efivar API
  patch for openSUSE Leap 42.x and SLE
* Thu Jul 21 2016 glin@suse.com
- Amend the spec file to detect SLE/openSUSE (bsc#990228)
* Fri Jul 15 2016 glin@suse.com
- Add fwupdate-fix-efivar-0.24-api.patch to fix the compilation
  errors due to the change of efivar APIs
- Bump BuildRequires of efivar-devel to 0.24
- Add fwupdate-unset-immutable-flag.patch to unset the immutable
  flag before clean the EFI variables (bsc#964726)
- Amend fwupdate-suse-build.patch (FATE#319345)
  + omit the build-id and package fwudpate-efi-debuginfo in a less
    hacky way.
  + Use the RPM_OPT_FLAGS for the user space programs
- Add fwupdate-bsc988886-add-leading-space.patch to add the leading
  space to the load option (bsc#988886)
* Thu Jul  7 2016 glin@suse.com
- Correct the EFI dir for SLE-12-SP2 (FATE#319345)
- Install fwup*.efi to the EFI system partition (FATE#319345)
- Add fwupdate-bsc988000-set-a-mode-with-efi_set_variable.patch to
  fix the file mode (bsc#988000)
* Sun May  8 2016 jengelh@inai.de
- Drop unnecessary specfile elements.
  fwupdate seems not required for libfwup, remove the requirement.
- Correct requires of fwupdate-devel
- Use source URLs
* Fri May  6 2016 coolo@suse.com
- own bash-completion directory as no longer provided by
  util-linux (boo#977259)
* Mon Mar 28 2016 glin@suse.com
- Add the missing Group
* Wed Mar  2 2016 glin@suse.com
- initial import 0.5 (FATE#319345)
- Add fwupdate-suse-build.patch to change the destination of the
  EFI files and remove the po files
